import React, { memo, useState, useRef } from 'react';
import { Button, Card, CardBody, CardTitle, Grid, GridItem, Modal, ModalVariant, Text, TextContent, TextVariants, } from '@patternfly/react-core';
import { ExternalLinkAltIcon } from '@patternfly/react-icons';
import feedbackImage from '../images/pf_feedback.svg';
import { FeedbackForm } from './FeedbackForm';
import FeedbackSuccess from './FeedbackSuccess';
import FeedbackError from './FeedbackError';
import '../Feedback/Feedback.css';
import { LocaleContext } from '../context/LocaleContext';
export const FeedbackModalInternal = memo(({ email, isOpen, onShareFeedback, onJoinMailingList, onReportABug, onOpenSupportCase, onClose, feedbackImg }) => {
    const intl = React.useContext(LocaleContext);
    const emailRef = useRef(email ? email : '');
    const [modalPage, setModalPage] = useState('feedbackHome');
    const handleCloseModal = () => {
        if (onClose) {
            onClose();
        }
        setModalPage("feedbackHome");
    };
    const updateEmail = (email) => { if (emailRef.current !== email && email !== '') {
        emailRef.current = email;
    } };
    const onSubmit = (feedbackPage, results) => {
        if (results instanceof Promise) {
            results.then((results) => {
                results === false ? setModalPage("feedbackError") : setModalPage(feedbackPage);
            });
        }
        else {
            results === false ? setModalPage("feedbackError") : setModalPage(feedbackPage);
        }
    };
    const ModalDescription = ({ modalPage }) => {
        switch (modalPage) {
            case 'feedbackHome':
                return (React.createElement("div", { className: "chr-c-feedback-content" },
                    React.createElement(TextContent, null,
                        React.createElement(Text, { component: TextVariants.h1 }, intl.tellAboutExperience),
                        React.createElement(Text, null, intl.helpUsImproveHCC)),
                    React.createElement("div", { className: "chr-c-feedback-cards" },
                        React.createElement(Card, { isSelectableRaised: true, isCompact: true, onClick: () => { typeof onShareFeedback === 'string' ? window.open(onShareFeedback, '_blank') : setModalPage('feedbackOne'); } },
                            React.createElement(CardTitle, { className: "chr-c-feedback-card-title" },
                                intl.shareFeedback,
                                " ",
                                typeof onShareFeedback === 'string' ? React.createElement(ExternalLinkAltIcon, null) : null),
                            React.createElement(CardBody, null,
                                intl.howIsConsoleExperience,
                                " ")),
                        React.createElement("br", null),
                        onReportABug ?
                            React.createElement(React.Fragment, null,
                                React.createElement(Card, { isSelectableRaised: true, isCompact: true, onClick: () => { typeof onReportABug === 'string' ? window.open(onReportABug, '_blank') : setModalPage('reportBugOne'); } },
                                    React.createElement(CardTitle, { className: "chr-c-feedback-card-title" },
                                        intl.reportABug,
                                        " ",
                                        typeof onReportABug === 'string' ? React.createElement(ExternalLinkAltIcon, null) : null,
                                        " "),
                                    React.createElement(CardBody, null, intl.describeBugUrgentCases)),
                                React.createElement("br", null)) : null,
                        onOpenSupportCase ? React.createElement(Card, { isSelectableRaised: true, isCompact: true, onClick: () => {
                                window.open(onOpenSupportCase, '_blank');
                            } },
                            React.createElement(CardTitle, { className: "chr-c-feedback-card-title" },
                                React.createElement(Text, null,
                                    intl.openSupportCase,
                                    " ",
                                    React.createElement(ExternalLinkAltIcon, null))),
                            React.createElement(CardBody, null, intl.getSupport)) : null,
                        React.createElement("br", null),
                        onJoinMailingList ?
                            React.createElement(Card, { isSelectableRaised: true, isCompact: true, onClick: () => { typeof onJoinMailingList === 'string' ? window.open(onJoinMailingList, '_blank') : setModalPage('informDirection'); } },
                                React.createElement(CardTitle, { className: "chr-c-feedback-card-title" },
                                    React.createElement(Text, null,
                                        intl.informDirection,
                                        " ",
                                        typeof onJoinMailingList === 'string' ? React.createElement(ExternalLinkAltIcon, null) : null)),
                                React.createElement(CardBody, null, intl.learnAboutResearchOpportunities)) : null),
                    React.createElement(Button, { className: "chr-c-feedback-button", ouiaId: "cancel-feedback", key: "cancel", variant: "link", onClick: handleCloseModal }, intl.cancel)));
            case 'feedbackOne':
                return (React.createElement(FeedbackForm, { email: emailRef.current, onCloseModal: handleCloseModal, onSubmit: (email, textAreaValue) => {
                        let results = true;
                        if (onShareFeedback && typeof onShareFeedback === 'function') {
                            results = onShareFeedback(email, textAreaValue);
                            updateEmail(email);
                        }
                        onSubmit('feedbackSuccess', results);
                    }, onClickBack: () => setModalPage('feedbackHome'), handleFeedbackError: () => setModalPage('feedbackError'), modalTitle: intl.shareYourFeedback, textareaLabel: intl.enterFeedback, feedbackType: "Feedback", checkboxDescription: intl.learnAboutResearchOpportunities, submitTitle: intl.submitFeedback }));
            case 'reportBugOne':
                return (React.createElement(FeedbackForm, { email: emailRef.current, onCloseModal: handleCloseModal, onSubmit: (email, textAreaValue) => {
                        let results = true;
                        if (onReportABug && typeof onReportABug === 'function') {
                            results = onReportABug(email, textAreaValue);
                            updateEmail(email);
                        }
                        onSubmit('bugReportSuccess', results);
                    }, onClickBack: () => setModalPage('feedbackHome'), handleFeedbackError: () => setModalPage('feedbackError'), modalTitle: intl.reportABug, modalDescription: React.createElement(Text, null,
                        intl.describeReportBug,
                        ' ',
                        React.createElement(Text, { component: "a", href: "https://access.redhat.com/support/cases/#/case/new/open-case?caseCreate=true", target: "_blank" },
                            intl.openSupportCase,
                            " ",
                            React.createElement(ExternalLinkAltIcon, null))), feedbackType: "Bug", checkboxDescription: `${intl.learnAboutResearchOpportunities} ${intl.weNeverSharePersonalInformation}`, submitTitle: intl.submitFeedback }));
            case 'informDirection':
                return (React.createElement(FeedbackForm, { email: emailRef.current, onCloseModal: handleCloseModal, onSubmit: (email, _textAreaValue) => {
                        let results = true;
                        if (onJoinMailingList && typeof onJoinMailingList === 'function') {
                            results = onJoinMailingList(email);
                            updateEmail(email);
                        }
                        onSubmit('informDirectionSuccess', results);
                    }, onClickBack: () => setModalPage('feedbackHome'), handleFeedbackError: () => setModalPage('feedbackError'), modalTitle: intl.informDirection, modalDescription: React.createElement(Text, null,
                        intl.informDirectionDescription,
                        React.createElement(Text, { component: "a", href: "https://www.redhat.com/en/about/user-research", target: "_blank" }, intl.userResearchTeam),
                        intl.directInfluence), feedbackType: "[Research Opportunities]", textAreaHidden: true, checkboxDescription: intl.weNeverSharePersonalInformation, submitTitle: intl.joinMailingList }));
            case 'feedbackSuccess':
                return (React.createElement(FeedbackSuccess, { successTitle: intl.feedbackSent, successDescription: intl.thankYouForFeedback, onCloseModal: handleCloseModal }));
            case 'bugReportSuccess':
                return (React.createElement(FeedbackSuccess, { successTitle: intl.bugReported, successDescription: intl.teamWillReviewBug, onCloseModal: handleCloseModal }));
            case 'informDirectionSuccess':
                return (React.createElement(FeedbackSuccess, { successTitle: intl.responseSent, successDescription: intl.thankYouForInterest, onCloseModal: handleCloseModal }));
            case 'feedbackError':
                return React.createElement(FeedbackError, { onCloseModal: handleCloseModal });
        }
    };
    return (React.createElement(React.Fragment, null,
        React.createElement(Modal, { "aria-label": "Feedback modal", isOpen: isOpen, className: "chr-c-feedback-modal", variant: ModalVariant.large, onClose: handleCloseModal },
            React.createElement(Grid, null,
                React.createElement(GridItem, { span: 8, rowSpan: 12 },
                    React.createElement(ModalDescription, { modalPage: modalPage })),
                React.createElement(GridItem, { span: 4, className: "chr-c-feedback-image" },
                    React.createElement("img", { alt: "feedback illustration", src: feedbackImg ? feedbackImg : feedbackImage }))))));
});
FeedbackModalInternal.displayName = 'FeedbackModal';
export default FeedbackModalInternal;
